AnnotationData class

Constructors

AnnotationData({required String fileName, List<Map<String, Object>>? drawingPaths, List<Map<String, Object>>? textAnnotations, required double pdfPageWidth, required double pdfPageHeight})

Properties

drawingPaths List<Map<String, Object>>?
getter/setter pair
fileName String
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
pdfPageHeight double
getter/setter pair
pdfPageWidth double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textAnnotations List<Map<String, Object>>?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

decode(Object result) AnnotationData